<?php

namespace DMG;

/**
 * Add a Liveblog settings page
 *
 * Class Liveblog_Settings
 *
 * @package DMG
 */
class Liveblog_Settings {

	const PAGE_SLUG = 'liveblog-settings';
	const DMG_LIVEBLOG_END_DATE_AUTOMATE = 'dmg_liveblog_end_date_automate';
	const DMG_LIVEBLOG_END_DATE_HOURS_BUMP = 'dmg_liveblog_end_date_hours_bump';
	const DMG_LIVEBLOG_LINK_AUTHOR_BYLINES = 'dmg_liveblog_link_author_bylines';
	const DMG_LIVEBLOG_PRELOAD_ENTRIES = 'dmg_liveblog_preload_entries';
	const DMG_LIVEBLOG_PRELOAD_ENTRY_PAGE_COUNT = 'dmg_liveblog_preload_entry_page_count';
	const DMG_LIVEBLOG_CLEAR_PAGE_CACHE_ON_PUBLISH_NEW_ENTRY= 'dmg_liveblog_clear_page_cache_on_publish_new_entry';

	/**
	 * Initialize actions
	 */
	public static function init() {
		add_action( 'admin_menu', [ __CLASS__, 'add_page' ] );
		add_action( 'admin_init', [ __CLASS__, 'register_fields' ] );
	}

	/**
	 * Add the page under Settings
	 */
	public static function add_page() {
		// Get the page name when we add the submenu page
		add_submenu_page(
			'options-general.php',
			'Liveblog Settings',
			'Liveblog Settings',
			Liveblog_Post_Type::CAPABILITY,
			self::PAGE_SLUG,
			[ __CLASS__, 'page_callback' ]
		);
	}


	/**
	 * The settings page callback
	 */
	public static function page_callback() {
		?>
        <div class="wrap">
            <h2>Liveblog Settings</h2>
            <form method="post" id="<? echo self::PAGE_SLUG; ?>" action="options.php">
				<?php
				settings_fields( self::PAGE_SLUG );
				do_settings_sections( self::PAGE_SLUG );
				submit_button( 'Save Changes', 'primary', 'submit', true, [ 'id' => 'submit' ] );
				?>
            </form>
        </div>
		<?php
	}

	/**
	 * Register the fields to display in the settings page
	 */
	public static function register_fields() {

		add_settings_section( sprintf( '%s-general', self::PAGE_SLUG ), '', '__return_false', self::PAGE_SLUG );

		self::register_setting( self::DMG_LIVEBLOG_END_DATE_AUTOMATE, 'Automate End Date Bump', '', 'field_checkbox' );
		self::register_setting( self::DMG_LIVEBLOG_END_DATE_HOURS_BUMP, 'How many hours ahead?', 'If Automate End Date Bump is enabled then increase the coverageEndTime value to be the publish date of last entry plus the hours specified in this field.' );
		self::register_setting( self::DMG_LIVEBLOG_LINK_AUTHOR_BYLINES, 'Link author bylines on entries', '', 'field_checkbox' );
		self::register_setting( self::DMG_LIVEBLOG_PRELOAD_ENTRIES, 'Preload entries on initial load', '', 'field_checkbox' );
		self::register_setting( self::DMG_LIVEBLOG_PRELOAD_ENTRY_PAGE_COUNT, 'Preloaded entry page count', 'The number of pages to preload into the liveblog container' );
		self::register_setting( self::DMG_LIVEBLOG_CLEAR_PAGE_CACHE_ON_PUBLISH_NEW_ENTRY, 'Clear page page on entry publish', '', 'field_checkbox' );

	}

	/**
	 * Add the settings field
	 *
	 * @param $id
	 * @param $label
	 * @param string $note
	 * @param string $form_field
	 */
	public static function register_setting( $id, $label, $note = '', $form_field = 'field_input' ) {

		add_settings_field(
			$id,
			'<label for="' . esc_attr( $id ) . '">' . esc_attr( $label ) . '</label>',
			[ __CLASS__, $form_field ],
			self::PAGE_SLUG,
			sprintf( '%s-general', self::PAGE_SLUG ),
			[ $id, $note ]
		);
		register_setting( self::PAGE_SLUG, $id );

	}

	/**
	 * Generate the input text field
	 *
	 * @param $args
	 */
	public static function field_input( $args ) {
		$value = get_option( $args[0] );
		printf( '<input type="text" id="%1$s" name="%1$s" value="%2$s" class="regular-text" />', esc_attr( $args[0] ), esc_attr( $value ) );
		if ( $args[1] ) {
			printf( '<small class="admin-note">%s</small>', esc_html( $args[1] ) );
		}
	}

	/**
	 * Generate the checkbox field
	 *
	 * @param $args
	 */
	public static function field_checkbox( $args ) {
		$option_value = get_option( $args[0] );

		$checked = $option_value ? "checked=\"checked\"" : "";

		printf( '<div><input type="checkbox" name="%s"  value="1" %s><label for="%s">Enable</label></div>',
			esc_attr( $args[0] ), $checked, esc_attr( $args[0] ) );
	}
}
